@@ -50,22 +50,6 @@
 #include <QEventLoopLocker>
 #include <QPointer>
 
-class DeleteLaterRAII
-{
-public:
-    DeleteLaterRAII(QObject *obj) : mObj(obj)
-    {}
-    ~DeleteLaterRAII()
-    {
-        if (mObj) {
-            mObj->deleteLater();
-        }
-    }
-private:
-    Q_DISABLE_COPY(DeleteLaterRAII)
-    QPointer<QObject> mObj;
-};
-
 class KeyGenerationJob : public QObject
 {
     Q_OBJECT
@@ -265,7 +249,7 @@ public:
     KeyImportJob(const QString &file, Kleo::KeySelectionCombo *parent)
         : QGpgME::Job(parent)
         , mFile(file)
-        , mJob(Q_NULLPTR)
+        , mJob(nullptr)
     {
     }
 
@@ -282,7 +266,7 @@ public:
 
     void start()
     {
-        QGpgME::ImportJob *job = Q_NULLPTR;
+        QGpgME::ImportJob *job = nullptr;
         switch (Kleo::findProtocol(mFile)) {
         case GpgME::OpenPGP:
             job = QGpgME::openpgp()->importJob();
@@ -291,7 +275,7 @@ public:
             job = QGpgME::smime()->importJob();
             break;
         default:
-            job = Q_NULLPTR;
+            job = nullptr;
             break;
         }
 
@@ -320,7 +304,7 @@ public:
 
     void keyImported(const GpgME::ImportResult &result)
     {
-        mJob = Q_NULLPTR;
+        mJob = nullptr;
         if (result.error()) {
             KMessageBox::error(qobject_cast<QWidget *>(parent()),
                                i18n("Failed to import key: %1", QString::fromUtf8(result.error().asString())),
