@@ -35,11 +35,11 @@
 #include <KMime/Message>
 
 #include <klocalizedstring.h>
-#include <kross/core/action.h>
 #include "accountwizard_debug.h"
 #include <kmessagebox.h>
 #include <qplatformdefs.h>
 #include <KAboutData>
+#include <PimCommon/PimUtil>
 
 #include <KHelpMenu>
 
@@ -109,6 +109,8 @@ Dialog::Dialog(QWidget *parent)
     //Initialize menu
     QMenu *menu = helpMenu->menu();
     helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("akonadi")));
+    disconnect(helpMenu->action(KHelpMenu::menuHelpContents), 0, helpMenu, 0);
+    connect(helpMenu->action(KHelpMenu::menuHelpContents), &QAction::triggered, this, &Dialog::slotOpenHelp);
     button(QDialogButtonBox::Help)->setMenu(menu);
 }
 
@@ -213,3 +215,7 @@ void Dialog::reject()
     mSetupManager->requestRollback();
 }
 
+void Dialog::slotOpenHelp()
+{
+    PimCommon::Util::invokeHelp(QStringLiteral("kmail2/getting-started.html"), QStringLiteral("account-wizard"));
+}
