@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2010 Laurent Montel <montel@kde.org>
+    Copyright (C) 2010-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -29,14 +29,13 @@ class Transport;
 namespace KIdentityManagement
 {
 class Identity;
-class IdentityManager;
 }
 
 class Identity : public SetupObject
 {
     Q_OBJECT
 public:
-    explicit Identity(QObject *parent = Q_NULLPTR);
+    explicit Identity(QObject *parent = nullptr);
     ~Identity();
     void create() Q_DECL_OVERRIDE;
     void destroy() Q_DECL_OVERRIDE;
