@@ -45,7 +45,7 @@ int main(int argc, char **argv)
                          QStringLiteral("0.2"),
                          i18n("Helps setting up PIM accounts"),
                          KAboutLicense::LGPL,
-                         i18n("(c) 2009-2016 the Akonadi developers"),
+                         i18n("(c) 2009-2017 the Akonadi developers"),
                          QStringLiteral("http://pim.kde.org/akonadi/"));
     aboutData.addAuthor(i18n("Volker Krause"),  i18n("Author"), QStringLiteral("vkrause@kde.org"));
     aboutData.addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
@@ -65,7 +65,7 @@ int main(int argc, char **argv)
     aboutData.processCommandLine(&parser);
     KDBusService service(KDBusService::Unique);
 
-    Akonadi::ControlGui::start(0);
+    Akonadi::ControlGui::start(nullptr);
 
     const QString packageArgument = parser.value(QStringLiteral("package"));
     if (!packageArgument.isEmpty()) {
@@ -79,7 +79,7 @@ int main(int argc, char **argv)
         Global::setTypeFilter(typeValue.split(QLatin1Char(',')));
     }
 
-    Dialog dlg(0);
+    Dialog dlg(nullptr);
     dlg.show();
     // Unregister once the UI is closed, even if the app will continue running
     // and generating keys in the background.
