@@ -1,7 +1,7 @@
 /*
     Copyright (c) 2009 Volker Krause <vkrause@kde.org>
     Copyright (c) 2010 Tom Albers <toma@kde.org>
-    Copyright (c) 2012 Laurent Montel <montel@kde.org>
+    Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -43,7 +43,7 @@ QString accountName(Ispdb *ispdb, QString username)
 }
 
 PersonalDataPage::PersonalDataPage(Dialog *parent) :
-    Page(parent), mIspdb(0), mSetupManager(parent->setupManager())
+    Page(parent), mIspdb(nullptr), mSetupManager(parent->setupManager())
 {
     QWidget *pageParent = this;
 
@@ -217,6 +217,7 @@ void PersonalDataPage::configureImapAccount()
         case Ispdb::GSSAPI: t->setOption(QStringLiteral("Authentication"), MailTransport::Transport::EnumAuthenticationType::GSSAPI); break;
         case Ispdb::ClientIP: break;
         case Ispdb::NoAuth: break;
+        case Ispdb::OAuth2: t->setOption(QStringLiteral("Authentication"), MailTransport::Transport::EnumAuthenticationType::XOAUTH2); break;
         default: break;
         }
         switch (s.socketType) {
