@@ -62,14 +62,14 @@ void ProviderPage::fillModel(const KNS3::Entry::List &list)
 {
     if (m_fetchItem) {
         m_model->removeRows(m_model->indexFromItem(m_fetchItem).row(), 1);
-        m_fetchItem = Q_NULLPTR;
+        m_fetchItem = nullptr;
     }
 
     // KNS3::Entry::Entry() is private, so we need to save the whole list.
     // we can not use a QHash or whatever, as that needs that constructor...
     m_providerEntries = list;
 
-    foreach (const KNS3::Entry &e, list) {
+    for (const KNS3::Entry &e : list) {
         qCDebug(ACCOUNTWIZARD_LOG) << "Found Entry: " << e.name();
 
         QStandardItem *item = new QStandardItem(e.name());
@@ -138,7 +138,7 @@ void ProviderPage::providerStatusChanged(const KNS3::Entry &e)
 
 void ProviderPage::findDesktopAndSetAssistant(const QStringList &list)
 {
-    foreach (const QString &file, list) {
+    for (const QString &file : list) {
         qCDebug(ACCOUNTWIZARD_LOG) << file;
         if (file.endsWith(QStringLiteral(".desktop"))) {
             qCDebug(ACCOUNTWIZARD_LOG) << "Yay, a desktop file!" << file;
