@@ -38,9 +38,9 @@
 
 SetupManager::SetupManager(QWidget *parent) :
     QObject(parent),
-    m_currentSetupObject(Q_NULLPTR),
-    m_page(Q_NULLPTR),
-    m_wallet(Q_NULLPTR),
+    m_currentSetupObject(nullptr),
+    m_page(nullptr),
+    m_wallet(nullptr),
     m_keyPublishingMethod(Key::NoPublishing),
     m_personalDataAvailable(false),
     m_rollbackRequested(false),
@@ -148,7 +148,7 @@ void SetupManager::setupSucceeded(const QString &msg)
     if (m_currentSetupObject) {
         Q_EMIT setupFinished(m_currentSetupObject);
         m_setupObjects.append(m_currentSetupObject);
-        m_currentSetupObject = 0;
+        m_currentSetupObject = nullptr;
     }
     setupNext();
 }
@@ -159,7 +159,7 @@ void SetupManager::setupFailed(const QString &msg)
     m_page->addMessage(SetupPage::Error, msg);
     if (m_currentSetupObject) {
         m_setupObjects.append(m_currentSetupObject);
-        m_currentSetupObject = 0;
+        m_currentSetupObject = nullptr;
     }
     rollback();
 }
